

.. image:: https://readthedocs.org/projects/pdb-manip-py/badge/?version=latest
    :target: https://pdb-manip-py.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://travis-ci.org/samuelmurail/pdb_manip_py.svg?branch=master
    :target: https://travis-ci.org/samuelmurail/pdb_manip_py

.. image:: https://codecov.io/gh/samuelmurail/pdb_manip_py/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/samuelmurail/pdb_manip_py

.. image:: https://img.shields.io/pypi/v/pdb_manip_py.svg
        :target: https://pypi.python.org/pypi/pdb_manip_py

.. image:: https://img.shields.io/conda/vn/conda-forge/pdb_manip_py.svg
        :target: https://anaconda.org/conda-forge/pdb_manip_py

Pdb_Manip_py
=======================================


Pdb_Manip_py is a python library allowing simple operations on pdb coor files.

* Online Documentation:
   https://pdb-manip-py.readthedocs.io

* Source code repository:
   https://github.com/samuelmurail/pdb_manip_py

Main features:
---------------------------------------

* Basic pdb operations
   - pdb wrapper
   - selection tools
   - rotation
   - translation
   - alignement
   - RMSD calculation
   - insertion of molecules in solvant
   - ...


Installation
---------------------------------------

Using Pypi
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. code-block:: bash

   pip3 install pdb_manip_py

Using Conda
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. code-block:: bash

   conda install pdb_manip_py -c conda-forge


From source code
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Get the os_command_py library from `github`_.

.. code-block:: bash

   git clone https://github.com/samuelmurail/pdb_manip_py.git
   ./setup.py install --user

.. _github: https://github.com/samuelmurail/pdb_manip_py


Author
---------------------------------------

* `Samuel Murail <https://samuelmurail.github.io/PersonalPage/>`_, Associate Professor - `Université Paris Diderot <https://www.univ-paris-diderot.fr>`_, `CMPLI <http://bfa.univ-paris-diderot.fr/equipe-8/>`_.

See also the list of `contributors <https://github.com/samuelmurail/os_command_py/contributors>`_ who participated in this project.

License
---------------------------------------

This project is licensed under the GNU General Public License v2.0 - see the ``LICENSE`` file for details.
